import unittest
from password_generator.generator import generate_password


class TestPasswordGenerator(unittest.TestCase):

    def test_password_length(self):
        password = generate_password(14)
        self.assertEqual(len(password), 14)

    def test_password_not_empty(self):
        password = generate_password()
        self.assertTrue(bool(password))

    def test_password_contains_all_characters(self):
        password = generate_password(20)
        self.assertTrue(any(c.isupper() for c in password))  # Uppercase check
        self.assertTrue(any(c.islower() for c in password))  # Lowercase check
        self.assertTrue(any(c.isdigit() for c in password))  # Digit check
        self.assertTrue(
            any(c in "!@#$%^&*()_+" for c in password)
        )  # Special char check

    def test_password_min_length(self):
        with self.assertRaises(ValueError):
            generate_password(6)  # Should raise an error


if __name__ == "__main__":
    unittest.main()



import random
import string


def generate_password(length=16):
    """
    Generate a strong, unique password of a given length.

    The password will contain:
    - Uppercase Letters (A-Z)
    - Lowercase Letters (a-z)
    - Digits (0-9)
    - Special Characters (!@#$%^&*()_+)

    :param length: Length of the password (default: 14)
    :return: Randomly generated secure password
    """
    if length < 8:
        raise ValueError("Password length must be at least 8 characters for security.")

    characters = (
        string.ascii_uppercase + string.ascii_lowercase + string.digits + "!@#$%^&*()_+"
    )

    password = "".join(random.choice(characters) for _ in range(length))

    return password



from setuptools import setup, find_packages

setup(
    name="secure_pass_gen",
    version="0.1.0",
    author="NIL MAKVANA",
    author_email="neel327.rejoice@gmail.com",
    description="A simple Python package to generate strong passwords.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/NIL327/password_generator",  # Update with your GitHub repo
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)


